@@ -1,4 +1,4 @@
-# $Id: cmon.py 1297 2015-03-24 19:51:12Z mwall $
+# $Id: cmon.py 1377 2015-10-27 22:32:30Z mwall $
 # Copyright 2013 Matthew Wall
 """weewx module that records cpu, memory, disk, and network usage.
 
@@ -125,7 +125,8 @@ import weeutil.weeutil
 from weewx.drivers import AbstractDevice
 from weewx.engine import StdService
 
-VERSION = "0.9"
+DRIVER_NAME = "ComputerMonitor"
+DRIVER_VERSION = "0.13"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -236,6 +237,7 @@ IGNORED_MOUNTS = [
     '/afs',
     '/mit',
     '/run',
+    '/var/lib/nfs',
     ]
 
 
@@ -509,7 +511,7 @@ class ComputerMonitorDriver(AbstractDevice):
     """Driver for collecting computer health data."""
 
     def __init__(self, **stn_dict):
-        loginf('driver version is %s' % VERSION)
+        loginf('driver version is %s' % DRIVER_VERSION)
         self.polling_interval = int(stn_dict.get('polling_interval', 10))
         loginf('polling interval is %s' % self.polling_interval)
 
@@ -536,7 +538,7 @@ class ComputerMonitor(StdService):
 
     def __init__(self, engine, config_dict):
         super(ComputerMonitor, self).__init__(engine, config_dict)
-        loginf("service version is %s" % VERSION)
+        loginf("service version is %s" % DRIVER_VERSION)
 
         d = config_dict.get('ComputerMonitor', {})
         self.max_age = weeutil.weeutil.to_int(d.get('max_age', 2592000))
@@ -612,6 +614,7 @@ if __name__=="__main__":
 
     def main():
         import optparse
+        import weecfg
         syslog.openlog('wee_cmon', syslog.LOG_PID | syslog.LOG_CONS)
         parser = optparse.OptionParser(usage=usage)
         parser.add_option('--config', dest='cfgfn', type=str, metavar="FILE",
@@ -630,7 +633,7 @@ if __name__=="__main__":
         (options, args) = parser.parse_args()
 
         if options.update:
-            _, config_dict = weeutil.weeutil.read_config(options.cfgfn, args)
+            _, config_dict = weecfg.read_config(options.cfgfn, args)
             update_to_v3(config_dict, options.binding)
         elif options.tc:
             test_collector()
@@ -641,6 +644,7 @@ if __name__=="__main__":
 
     def update_to_v3(config_dict, db_binding):
         import weedb
+        import sqlite3
         from weewx.manager import Manager
 
         # update an old schema to v3-compatible.  this means adding the
@@ -662,7 +666,7 @@ if __name__=="__main__":
             return
 
         # make a copy of the database dict
-        new_db_dict = mgr_dict['database_dict'].dict()
+        new_db_dict = dict(mgr_dict['database_dict'])
         # modify the database name
         new_db_dict['database_name'] = mgr_dict['database_dict']['database_name'] + '_new'
         # see if the new db exists.  if so, see if we can delete it
@@ -677,11 +681,13 @@ if __name__=="__main__":
                 elif ans == 'n':
                     print "update aborted"
                     return
+        except sqlite3.OperationalError:
+            pass
 
         # see if we really should do this
         ans = None
         while ans not in ['y', 'n']:
-            ans = raw_input("Create new database (y/n)? ")
+            ans = raw_input("Create new database %s (y/n)? " % new_db_dict['database_name'])
             if ans == 'y':
                 break
             elif ans == 'n':
@@ -689,9 +695,18 @@ if __name__=="__main__":
                 return
 
         # copy the data over
+        cnt = 0
         with Manager.open(mgr_dict['database_dict']) as old_mgr:
             with Manager.open_with_create(new_db_dict, schema=s) as new_mgr:
-                new_mgr.addRecord(old_mgr.genBatchRecords())
+                last_ts = None
+                for r in old_mgr.genBatchRecords():
+                    cnt += 1
+                    print "record %d\r" % cnt,
+                    ival = r['dateTime'] - last_ts if last_ts else 0
+                    r['interval'] = ival
+                    new_mgr.addRecord(r)
+                    last_ts = r['dateTime']
+        print "copied %d records\n" % cnt
 
     def test_collector():
         c = get_collector()
